def factorial(n):
  if n == 0:
    return 1
  else:
    return n * factorial(n - 1)

def sig(n):
	if n == 0:
		return 0
	else:
		return n + sig(n - 1)

def recpow(n):
	if n == 0:
		return 1
	else:
		return n ** recpow(n - 1)

def incr(n):
	return n + 1

def decr(n):
	return n - 1

def pow(n, p):
	if p == 0:
		return 1
	else:
		return n**p

def mod(n, d):
	return n % d

def _recur_fibo(n):  
   if n <= 1:  
       return n  
   else:  
       return(_recur_fibo(n-1) + _recur_fibo(n-2))

def get_fib(terms):
	if terms <= 0:
		raise ValueError
	else:
		fib = []
		for i in range(terms):
			fib.append(_recur_fibo(i))
		return fib

pi = 22/7



class Property:
	def __init__(self):
		pass

	def add(self, name, val):
		if type(name) == str:
			if " " in name or "1" in name or "2" in name or "3" in name or "4" in name or "5" in name or "6" in name or "7" in name or "8" in name or "9" in name:
				raise SyntaxError("You put a number or space in the name!")
				return
			else: setattr(self, name, val)
		else: raise TypeError("That is not a string!")

	def remove(self, name):
		if type(name) == str:
			if " " in name or "1" in name or "2" in name or "3" in name or "4" in name or "5" in name or "6" in name or "7" in name or "8" in name or "9" in name:
				raise SyntaxError("You put a number or space in the name!")
				return
			else: delattr(self, name)
		else: raise TypeError("That is not a string!")

	def get(self, name):
		if type(name) == str:
			if " " in name or "1" in name or "2" in name or "3" in name or "4" in name or "5" in name or "6" in name or "7" in name or "8" in name or "9" in name:
				raise SyntaxError("You put a number or space in the name!")
				return
			else: return getattr(self, name)
		else: raise TypeError("That is not a string!")
